@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -53,6 +52,7 @@
 #ifndef ECFREEBUSYDATA_H
 #define ECFREEBUSYDATA_H
 
+#include "zcdefs.h"
 #include "freebusy.h"
 #include "freebusyguid.h"
 
@@ -88,13 +88,13 @@ public:
 	virtual HRESULT GetFBPublishRange(LONG *prtmStart, LONG *prtmEnd);
 
 public:
-	class xFreeBusyData : public IFreeBusyData
+	class xFreeBusyData _final : public IFreeBusyData
 	{
 		public:
 			// From IUnknown
-			virtual HRESULT __stdcall QueryInterface(REFIID refiid , void** lppInterface);
-			virtual ULONG __stdcall AddRef();
-			virtual ULONG __stdcall Release();
+			virtual HRESULT __stdcall QueryInterface(REFIID refiid , void **lppInterface) _override;
+			virtual ULONG __stdcall AddRef(void) _override;
+			virtual ULONG __stdcall Release(void) _override;
 
 			// From IFreeBusyData
 			virtual HRESULT __stdcall Reload(void*);
