@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -53,6 +52,7 @@
 #ifndef ECFREEBUSYSUPPORT_H
 #define ECFREEBUSYSUPPORT_H
 
+#include "zcdefs.h"
 #include "freebusy.h"
 #include "freebusyguid.h"
 
@@ -115,13 +115,13 @@ public:
 
 public:
 	// Interface voor Outlook 2002 and up
-	class xFreeBusySupport : public IFreeBusySupport
+	class xFreeBusySupport _final : public IFreeBusySupport
 	{
 		public:
 			// From IUnknown
-			virtual HRESULT __stdcall QueryInterface(REFIID refiid, void **lppInterface);
-			virtual ULONG __stdcall AddRef();
-			virtual ULONG __stdcall Release();
+			virtual HRESULT __stdcall QueryInterface(REFIID refiid, void **lppInterface) _override;
+			virtual ULONG __stdcall AddRef(void) _override;
+			virtual ULONG __stdcall Release(void) _override;
 
 			// From IFreeBusySupport
 			virtual HRESULT __stdcall Open(IMAPISession* lpMAPISession, IMsgStore* lpMsgStore, BOOL bStore);
@@ -153,13 +153,12 @@ public:
 	} m_xFreeBusySupport;
 
 	// Interface for Outlook 2000
-	class xFreeBusySupportOutlook2000 : public IFreeBusySupportOutlook2000
-	{
+	class xFreeBusySupportOutlook2000 _final : public IFreeBusySupportOutlook2000 {
 		public:
 			// From IUnknown
-			virtual HRESULT __stdcall QueryInterface(REFIID refiid, void **lppInterface);
-			virtual ULONG __stdcall AddRef();
-			virtual ULONG __stdcall Release();
+			virtual HRESULT __stdcall QueryInterface(REFIID refiid, void **lppInterface) _override;
+			virtual ULONG __stdcall AddRef(void) _override;
+			virtual ULONG __stdcall Release(void) _override;
 
 			// From IFreeBusySupport
 			virtual HRESULT __stdcall Open(IMAPISession* lpMAPISession, IMsgStore* lpMsgStore, BOOL bStore);
