@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -56,11 +55,11 @@ extern const unsigned int	g_cbEveryoneEid;
 extern unsigned char		*g_lpSystemEid;
 extern const unsigned int	g_cbSystemEid;
 
-HRESULT EntryIdIsDefault(unsigned int cbEntryId, LPENTRYID lpEntryId, bool *lpbResult);
-HRESULT EntryIdIsSystem(unsigned int cbEntryId, LPENTRYID lpEntryId, bool *lpbResult);
-HRESULT EntryIdIsEveryone(unsigned int cbEntryId, LPENTRYID lpEntryId, bool *lpbResult);
-HRESULT GetNonPortableObjectId(unsigned int cbEntryId, LPENTRYID lpEntryId, unsigned int *lpulObjectId);
-HRESULT GetNonPortableObjectType(unsigned int cbEntryId, LPENTRYID lpEntryId, ULONG *lpulObjectType);
-HRESULT GeneralizeEntryIdInPlace(unsigned int cbEntryId, LPENTRYID lpEntryId);
+HRESULT EntryIdIsDefault(unsigned int cbEntryId, const ENTRYID *lpEntryId, bool *lpbResult);
+HRESULT EntryIdIsSystem(unsigned int cbEntryId, const ENTRYID *lpEntryId, bool *lpbResult);
+HRESULT EntryIdIsEveryone(unsigned int cbEntryId, const ENTRYID *lpEntryId, bool *lpbResult);
+HRESULT GetNonPortableObjectId(unsigned int cbEntryId, const ENTRYID *lpEntryId, unsigned int *lpulObjectId);
+HRESULT GetNonPortableObjectType(unsigned int cbEntryId, const ENTRYID *lpEntryId, ULONG *lpulObjectType);
+HRESULT GeneralizeEntryIdInPlace(unsigned int cbEntryId, const ENTRYID *lpEntryId);
 
 #endif
