@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -42,6 +41,8 @@
  * 
  */
 
+#include "platform.h"
+
 #ifndef ECDEFS_H
 #define ECDEFS_H
 
@@ -247,13 +248,13 @@ typedef struct _sECPermission {
 typedef struct _sECQuota {
 	bool			bUseDefaultQuota;
 	bool			bIsUserDefaultQuota; // Default quota for users within company
-	long long		llWarnSize;
-	long long		llSoftSize;
-	long long		llHardSize;
+	int64_t		llWarnSize;
+	int64_t		llSoftSize;
+	int64_t		llHardSize;
 }ECQUOTA, *LPECQUOTA;
 
 typedef struct _sECQuotaStatus {
-	long long		llStoreSize;
+	int64_t		llStoreSize;
 	eQuotaStatus	quotaStatus;
 }ECQUOTASTATUS, *LPECQUOTASTATUS;
 
