@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -45,6 +44,7 @@
 #ifndef ECIterators_INCLUDED
 #define ECIterators_INCLUDED
 
+#include "zcdefs.h"
 #include <boost/iterator/iterator_facade.hpp>
 #include <mapi_ptr.h>
 
@@ -80,7 +80,7 @@ private:
 };
 
 template <typename ContainerPtrType>
-class ECHierarchyIterator
+class ECHierarchyIterator _final
 	: public boost::iterator_facade<
 		ECHierarchyIterator<ContainerPtrType>,
 		ContainerPtrType,
@@ -139,7 +139,7 @@ private:
 };
 
 template <typename ContainerPtrType>
-class ECContentsIterator
+class ECContentsIterator _final
 	: public boost::iterator_facade<
 		ECContentsIterator<ContainerPtrType>,
 		ContainerPtrType,
