@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -45,6 +44,7 @@
 #ifndef ECRestrictionBuilder_INCLUDED
 #define ECRestrictionBuilder_INCLUDED
 
+#include "zcdefs.h"
 #include <mapidefs.h>
 
 #include <list>
@@ -72,7 +72,7 @@ public:
 	 * 								of the newly allocated restriction. This memory must be freed with
 	 * 								MAPIFreeBuffer.
 	 * @param[in]	ulFlags			When set to ECRestriction::Cheap, not all data will be copied to the 
-	 * 								new MAPI restriction. This is usefull if the ECRestriction will outlive
+	 * 								new MAPI restriction. This is useful if the ECRestriction will outlive
 	 * 								the MAPI restriction.
 	 */
 	HRESULT CreateMAPIRestriction(LPSRestriction *lppRestriction, ULONG ulFlags = 0) const;
@@ -125,7 +125,7 @@ protected:
  * constructors of the ECAndRestriction and the ECOrRestriction classes.
  * It's implicitly created by +-ing multiple ECRestriction objects.
  */
-class ECRestrictionList {
+class ECRestrictionList _final {
 public:
 	ECRestrictionList(const ECRestriction &res1, const ECRestriction &res2) {
 		m_list.push_back(ResPtr(res1.Clone()));
@@ -156,7 +156,7 @@ inline ECRestrictionList ECRestriction::operator+ (const ECRestriction &other) c
 	return ECRestrictionList(*this, other);
 }
 
-class ECAndRestriction : public ECRestriction {
+class ECAndRestriction _final : public ECRestriction {
 public:
 	ECAndRestriction() { }
 	ECAndRestriction(const ECRestrictionList &list);
@@ -165,8 +165,8 @@ public:
 	: m_lstRestrictions(1, ResPtr(restriction.Clone())) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 	HRESULT append(const ECRestriction &restriction) {
 		m_lstRestrictions.push_back(ResPtr(restriction.Clone()));
@@ -179,7 +179,7 @@ private:
 	ResList	m_lstRestrictions;
 };
 
-class ECOrRestriction : public ECRestriction {
+class ECOrRestriction _final : public ECRestriction {
 public:
 	ECOrRestriction() { }
 	ECOrRestriction(const ECRestrictionList &list);
@@ -188,8 +188,8 @@ public:
 	: m_lstRestrictions(1, ResPtr(restriction.Clone())) 
 	{ }
 	
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 	HRESULT append(const ECRestriction &restriction) {
 		m_lstRestrictions.push_back(ResPtr(restriction.Clone()));
@@ -202,14 +202,14 @@ private:
 	ResList	m_lstRestrictions;
 };
 
-class ECNotRestriction : public ECRestriction {
+class ECNotRestriction _final : public ECRestriction {
 public:
 	ECNotRestriction(const ECRestriction &restriction)
 	: m_ptrRestriction(ResPtr(restriction.Clone())) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ECNotRestriction(ResPtr ptrRestriction);
@@ -218,11 +218,11 @@ private:
 	ResPtr	m_ptrRestriction;
 };
 
-class ECContentRestriction : public ECRestriction {
+class ECContentRestriction _final : public ECRestriction {
 public:
 	ECContentRestriction(ULONG ulFuzzyLevel, ULONG ulPropTag, LPSPropValue lpProp, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
 	ECRestriction *Clone() const;
 
 private:
@@ -234,7 +234,7 @@ private:
 	PropPtr	m_ptrProp;
 };
 
-class ECBitMaskRestriction : public ECRestriction {
+class ECBitMaskRestriction _final : public ECRestriction {
 public:
 	ECBitMaskRestriction(ULONG relBMR, ULONG ulPropTag, ULONG ulMask)
 	: m_relBMR(relBMR)
@@ -242,8 +242,8 @@ public:
 	, m_ulMask(ulMask) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ULONG	m_relBMR;
@@ -251,12 +251,12 @@ private:
 	ULONG	m_ulMask;
 };
 
-class ECPropertyRestriction : public ECRestriction {
+class ECPropertyRestriction _final : public ECRestriction {
 public:
 	ECPropertyRestriction(ULONG relop, ULONG ulPropTag, LPSPropValue lpProp, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ECPropertyRestriction(ULONG relop, ULONG ulPropTag, PropPtr ptrProp);
@@ -267,7 +267,7 @@ private:
 	PropPtr	m_ptrProp;
 };
 
-class ECComparePropsRestriction : public ECRestriction {
+class ECComparePropsRestriction _final : public ECRestriction {
 public:
 	ECComparePropsRestriction(ULONG relop, ULONG ulPropTag1, ULONG ulPropTag2)
 	: m_relop(relop)
@@ -275,8 +275,8 @@ public:
 	, m_ulPropTag2(ulPropTag2)
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ULONG	m_relop;
@@ -284,7 +284,7 @@ private:
 	ULONG	m_ulPropTag2;
 };
 
-class ECSizeRestriction : public ECRestriction {
+class ECSizeRestriction _final : public ECRestriction {
 public:
 	ECSizeRestriction(ULONG relop, ULONG ulPropTag, ULONG cb)
 	: m_relop(relop)
@@ -292,8 +292,8 @@ public:
 	, m_cb(cb)
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ULONG	m_relop;
@@ -301,28 +301,28 @@ private:
 	ULONG	m_cb;
 };
 
-class ECExistRestriction : public ECRestriction {
+class ECExistRestriction _final : public ECRestriction {
 public:
 	ECExistRestriction(ULONG ulPropTag)
 	: m_ulPropTag(ulPropTag) 
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ULONG	m_ulPropTag;
 };
-        
-class ECSubRestriction : public ECRestriction {
+
+class ECSubRestriction _final : public ECRestriction {
 public:
 	ECSubRestriction(ULONG ulSubObject, const ECRestriction &restriction)
 	: m_ulSubObject(ulSubObject)
 	, m_ptrRestriction(ResPtr(restriction.Clone()))
 	{ }
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ECSubRestriction(ULONG ulSubObject, ResPtr ptrRestriction);
@@ -332,12 +332,12 @@ private:
 	ResPtr	m_ptrRestriction;
 };
 
-class ECCommentRestriction : public ECRestriction {
+class ECCommentRestriction _final : public ECRestriction {
 public:
 	ECCommentRestriction(const ECRestriction &restriction, ULONG cValues, LPSPropValue lpProp, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	ECCommentRestriction(ResPtr ptrRestriction, ULONG cValues, PropPtr ptrProp);
@@ -352,12 +352,12 @@ private:
  * This is a special class, which encapsulates a raw SRestriction structure to allow
  * prebuild or obtained restriction structures to be used in the ECRestriction model.
  */
-class ECRawRestriction : public ECRestriction {
+class ECRawRestriction _final : public ECRestriction {
 public:
 	ECRawRestriction(LPSRestriction lpRestriction, ULONG ulFlags = 0);
 
-	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const;
-	ECRestriction *Clone() const;
+	HRESULT GetMAPIRestriction(LPVOID lpBase, LPSRestriction lpRestriction, ULONG ulFlags) const _override;
+	ECRestriction *Clone() const _override;
 
 private:
 	typedef boost::shared_ptr<SRestriction>	RawResPtr;
