@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -163,6 +162,8 @@
 #define PR_EC_OUTOFOFFICE_SUBJECT		PROP_TAG(PT_TSTRING, 	PR_EC_BASE+0x62)
 #define PR_EC_OUTOFOFFICE_SUBJECT_A		PROP_TAG(PT_STRING8, 	PR_EC_BASE+0x62)
 #define PR_EC_OUTOFOFFICE_SUBJECT_W		PROP_TAG(PT_UNICODE, 	PR_EC_BASE+0x62)
+#define PR_EC_OUTOFOFFICE_FROM			PROP_TAG(PT_SYSTIME, 	PR_EC_BASE+0x63)
+#define PR_EC_OUTOFOFFICE_UNTIL			PROP_TAG(PT_SYSTIME, 	PR_EC_BASE+0x64)
 
 #define PR_EC_WEBACCESS_SETTINGS		PROP_TAG(PT_STRING8, 	PR_EC_BASE+0x70)
 #define PR_EC_RECIPIENT_HISTORY			PROP_TAG(PT_STRING8, 	PR_EC_BASE+0x71)
