@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -45,6 +44,7 @@
 #ifndef MAPINOTIFSINK_H
 #define MAPINOTIFSINK_H
 
+#include "zcdefs.h"
 #include <list>
 #include <mapi.h>
 #include <mapix.h>
@@ -52,16 +52,16 @@
 #include <pthread.h>
 #include "ECUnknown.h"
 
-class MAPINotifSink : public IMAPIAdviseSink {
+class MAPINotifSink _final : public IMAPIAdviseSink {
 public:
     static HRESULT Create(MAPINotifSink **lppSink);
     
-    virtual ULONG 	__stdcall 	AddRef();
-    virtual ULONG 	__stdcall 	Release();
+    virtual ULONG 	__stdcall 	AddRef(void) _override;
+    virtual ULONG 	__stdcall 	Release(void) _override;
     
-    virtual HRESULT __stdcall	QueryInterface(REFIID iid, void **lpvoid);
+    virtual HRESULT __stdcall	QueryInterface(REFIID iid, void **lpvoid) _override;
     
-    virtual ULONG 	__stdcall 	OnNotify(ULONG cNotif, LPNOTIFICATION lpNotifications);
+    virtual ULONG 	__stdcall 	OnNotify(ULONG cNotif, LPNOTIFICATION lpNotifications) _override;
     virtual HRESULT __stdcall 	GetNotifications(ULONG *lpcNotif, LPNOTIFICATION *lppNotifications, BOOL fNonBlock, ULONG timeout);
 
 private:
