@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -50,15 +49,15 @@
 #define TRACE_WARNING 3
 #define TRACE_INFO 4
 
-void TraceMapi(int time, char *func, char *format, ...);
-void TraceMapiLib(int time, char *func, char *format, ...);
-void TraceNotify(int time, char *func, char *format, ...);
-void TraceSoap(int time, char *func, char *format, ...);
-void TraceInternals(int time, char *action, char *func, char *format, ...);
-void TraceStream(int time, char *func, char *format, ...);
-void TraceECMapi(int time, char *func, char *format, ...);
-void TraceExt(int time, char *func, char *format, ...);
-void TraceRelease(char *format, ...);
+void TraceMapi(int time, const char *func, const char *format, ...);
+void TraceMapiLib(int time, const char *func, const char *format, ...);
+void TraceNotify(int time, const char *func, const char *format, ...);
+void TraceSoap(int time, const char *func, const char *format, ...);
+void TraceInternals(int time, const char *action, const char *func, const char *format, ...);
+void TraceStream(int time, const char *func, const char *format, ...);
+void TraceECMapi(int time, const char *func, const char *format, ...);
+void TraceExt(int time, const char *func, const char *format, ...);
+void TraceRelease(const char *format, ...);
 
 #define TRACE_RELEASE	TraceRelease
 
