@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -45,6 +44,8 @@
 #ifndef ZARAFACODE_H
 #define ZARAFACODE_H
 
+#include "platform.h"
+
 #define MAKE_ZARAFA_SCODE(sev,code) ( (((unsigned int)(sev)<<31) | ((unsigned int)(code))) )
 #define MAKE_ZARAFA_E( err ) (MAKE_ZARAFA_SCODE( 1, err ))
 #define MAKE_ZARAFA_W( warn ) (MAKE_ZARAFA_SCODE( 1, warn )) // This macro is broken, should be 0
@@ -112,8 +113,8 @@ typedef unsigned int ECRESULT;
 #define ZARAFA_OBJTYPE_MESSAGE			5
 
 // Sessions
-#define ECSESSIONID	unsigned long long
-#define ECSESSIONGROUPID unsigned long long
+#define ECSESSIONID	uint64_t
+#define ECSESSIONGROUPID uint64_t
 
 #define EC_NOTIFICATION_CHECK_FREQUENTY		(1000*2)
 #define EC_NOTIFICATION_CLOSE_TIMEOUT		(1000)
