@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -45,6 +44,7 @@
 #ifndef utf16string_INCLUDED
 #define utf16string_INCLUDED
 
+#include "zcdefs.h"
 #include <string>
 #include <stdexcept>
 
@@ -140,7 +140,7 @@ template<>
 
 // 16-bit character specializations
 template <>
-class iconv_charset<utf16string> {
+class iconv_charset<utf16string> _final {
 public:
 	static const char *name() {
 		return "UTF-16LE";
@@ -154,7 +154,7 @@ public:
 };
 
 template <>
-class iconv_charset<unsigned short*> {
+class iconv_charset<unsigned short *> _final {
 public:
 	static const char *name() {
 		return "UTF-16LE";
@@ -166,7 +166,7 @@ public:
 };
 
 template <>
-class iconv_charset<const unsigned short*> {
+class iconv_charset<const unsigned short *> _final {
 public:
 	static const char *name() {
 		return "UTF-16LE";
