@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -45,11 +44,11 @@
 #ifndef mapi_array_ptr_INCLUDED
 #define mapi_array_ptr_INCLUDED
 
+#include "zcdefs.h"
 #include <utility>
 
 template<typename _T>
-class mapi_array_proxy
-{
+class mapi_array_proxy _final {
 public:
 	typedef _T		value_type;
 	typedef _T**	pointerpointer;
@@ -65,8 +64,7 @@ private:
 
 
 template <typename _T>
-class mapi_array_ptr
-{
+class mapi_array_ptr _final {
 public:
 	typedef _T						value_type;
 	typedef _T*						pointer;
