@@ -11,14 +11,13 @@
  * license. Therefore any rights, title and interest in our trademarks 
  * remain entirely with us.
  * 
- * Our trademark policy, <http://www.zarafa.com/zarafa-trademark-policy>,
- * allows you to use our trademarks in connection with Propagation and 
- * certain other acts regarding the Program. In any case, if you propagate 
- * an unmodified version of the Program you are allowed to use the term 
- * "Zarafa" to indicate that you distribute the Program. Furthermore you 
- * may use our trademarks where it is necessary to indicate the intended 
- * purpose of a product or service provided you use it in accordance with 
- * honest business practices. For questions please contact Zarafa at 
+ * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
+ * in connection with Propagation and certain other acts regarding the Program.
+ * In any case, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the Program.
+ * Furthermore you may use our trademarks where it is necessary to indicate the
+ * intended purpose of a product or service provided you use it in accordance
+ * with honest business practices. For questions please contact Zarafa at
  * trademark@zarafa.com.
  *
  * The interactive user interface of the software displays an attribution 
@@ -51,9 +50,9 @@
 bool isrtfhtml(const char *buf, unsigned int len);
 bool isrtftext(const char *buf, unsigned int len);
 
-HRESULT HrExtractHTMLFromRTF(std::string &lpStrRTFIn, std::string &lpStrHTMLOut, ULONG ulCodepage);
-HRESULT HrExtractHTMLFromTextRTF(std::string &lpStrRTFIn, std::string &lpStrHTMLOut, ULONG ulCodepage);
-HRESULT HrExtractHTMLFromRealRTF(std::string &lpStrRTFIn, std::string &lpStrHTMLOut, ULONG ulCodepage);
-HRESULT HrExtractBODYFromTextRTF(std::string &lpStrRTFIn, std::wstring &strBodyOut);
+HRESULT HrExtractHTMLFromRTF(const std::string &lpStrRTFIn, std::string &lpStrHTMLOut, ULONG ulCodepage);
+HRESULT HrExtractHTMLFromTextRTF(const std::string &lpStrRTFIn, std::string &lpStrHTMLOut, ULONG ulCodepage);
+HRESULT HrExtractHTMLFromRealRTF(const std::string &lpStrRTFIn, std::string &lpStrHTMLOut, ULONG ulCodepage);
+HRESULT HrExtractBODYFromTextRTF(const std::string &lpStrRTFIn, std::wstring &strBodyOut);
 
 #endif
